==> savane-1.0.7+4.tar.gz: savane-1.0.7+4/frontend/php/account/first.php <==
<?php

# This file is part of the Savane project
# <http:#gna.org/projects/savane/>
#
# $Id: first.php,v 1.16 2004/11/22 08:25:48 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#
#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

require "../include/pre.php";
site_user_header(array('title'=>sprintf(_("Welcome to %s"),$GLOBALS['sys_name']),'toptab'=>'account'));

echo '<p><b>'.sprintf(_("Welcome to %s"),$GLOBALS['sys_name']).'</b></p>';

echo '<p><b>'.sprintf(_("You are now a registered user on %s."),$GLOBALS['sys_name']).'</b></p>';

echo '<p>'._("As a registered user, you can participate fully in the activities on the site.");
echo ' '.sprintf(_("You may now post items to issue trackers in %s, sign on as a project member, or even start your own project."),$GLOBALS['sys_name']).'</p>';

echo '<p>'.sprintf(_("You should take some time to read through the %ssite documentation%s so that you may take full advantage of %s."),'<a href="'.$GLOBALS['sys_home'].'faq/?group='.$GLOBALS['sys_unix_group_name'].'">','</a> ',$GLOBALS['sys_name']).'</p>';

echo '<p>'._("Enjoy the site").'</p>';

echo '<p>'.sprintf(_("-- the %s team."),$GLOBALS['sys_name']).'</p>';

site_user_footer(array());;

?>

==> savane-1.2.tar.gz: savane-1.2/frontend/php/account/first.php <==
<?php

# This file is part of the Savane project
# <http:#gna.org/projects/savane/>
#
# $Id: first.php,v 1.17 2005/06/30 17:19:33 toddy Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#
#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

require "../include/pre.php";
site_user_header(array('title'=>sprintf(_("Welcome to %s"),$GLOBALS['sys_name']),'toptab'=>'account'));

echo '<p><b>'.sprintf(_("Welcome to %s"),$GLOBALS['sys_name']).'</b></p>';

echo '<p><b>'.sprintf(_("You are now a registered user on %s."),$GLOBALS['sys_name']).'</b></p>';

echo '<p>'._("As a registered user, you can participate fully in the activities on the site.");
echo ' '.sprintf(_("You may now post items to issue trackers in %s, sign on as a project member, or even start your own project."),$GLOBALS['sys_name']).'</p>';

echo '<p>'.sprintf(_("You should take some time to read through the %ssite documentation%s so that you may take full advantage of %s."),'<a href="'.$GLOBALS['sys_home'].'faq/?group='.$GLOBALS['sys_unix_group_name'].'">','</a> ',$GLOBALS['sys_name']).'</p>';

echo '<p>'._("Enjoy the site").'</p>';

echo '<p>'.sprintf(_("-- the %s team."),$GLOBALS['sys_name']).'</p>';

site_user_footer(array());;

?>
